@@ -27,14 +27,18 @@ def config():
 def test_get_then_set(config):
     config_key = "datafusion.optimizer.filter_null_join_keys"
 
-    assert config.get(config_key).as_py() is False
+    assert config.get(config_key) == "false"
 
-    config.set(config_key, True)
-    assert config.get(config_key).as_py() is True
+    config.set(config_key, "true")
+    assert config.get(config_key) == "true"
 
 
 def test_get_all(config):
-    config.get_all()
+    config_dict = config.get_all()
+    assert (
+        config_dict["datafusion.catalog.create_default_catalog_and_schema"]
+        == "true"
+    )
 
 
 def test_get_invalid_config(config):
