@@ -44,6 +44,48 @@ from datafusion.expr import (
     Aggregate,
     Sort,
     Analyze,
+    Join,
+    JoinType,
+    JoinConstraint,
+    CrossJoin,
+    Union,
+    Like,
+    ILike,
+    SimilarTo,
+    ScalarVariable,
+    Alias,
+    GetIndexedField,
+    Not,
+    IsNotNull,
+    IsTrue,
+    IsFalse,
+    IsUnknown,
+    IsNotTrue,
+    IsNotFalse,
+    IsNotUnknown,
+    Negative,
+    ScalarFunction,
+    BuiltinScalarFunction,
+    InList,
+    Exists,
+    Subquery,
+    InSubquery,
+    ScalarSubquery,
+    GroupingSet,
+    Placeholder,
+    Case,
+    Cast,
+    TryCast,
+    SubqueryAlias,
+    Between,
+    Explain,
+    Extension,
+    CreateMemoryTable,
+    CreateView,
+    Distinct,
+    DropTable,
+    Repartition,
+    Partitioning,
 )
 
 
@@ -77,6 +119,48 @@ def test_class_module_is_datafusion():
         Limit,
         Filter,
         Analyze,
+        Join,
+        JoinType,
+        JoinConstraint,
+        CrossJoin,
+        Union,
+        Like,
+        ILike,
+        SimilarTo,
+        ScalarVariable,
+        Alias,
+        GetIndexedField,
+        Not,
+        IsNotNull,
+        IsTrue,
+        IsFalse,
+        IsUnknown,
+        IsNotTrue,
+        IsNotFalse,
+        IsNotUnknown,
+        Negative,
+        ScalarFunction,
+        BuiltinScalarFunction,
+        InList,
+        Exists,
+        Subquery,
+        InSubquery,
+        ScalarSubquery,
+        GroupingSet,
+        Placeholder,
+        Case,
+        Cast,
+        TryCast,
+        Between,
+        SubqueryAlias,
+        Explain,
+        Extension,
+        CreateMemoryTable,
+        CreateView,
+        Distinct,
+        DropTable,
+        Repartition,
+        Partitioning,
     ]:
         assert klass.__module__ == "datafusion.expr"
 
